@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponse.h 2168 2006-12-03 20:56:04Z svn $
+ * $Id: ApacheResponse.h 2220 2006-12-10 06:10:27Z svn $
  *****************************************************************************/
 
 #ifndef APACHE_RESPONSE_H
@@ -34,6 +34,7 @@
 #include "Environment.h"
 
 #include "apr_strings.h"
+#include "apr_network_io.h"
 
 #include "Uncopyable.h"
 
@@ -95,6 +96,10 @@ public:
     {
         return r->connection->remote_ip;
     };
+    static apr_sockaddr_t *get_remote_addr(Handle *r)
+    {
+        return r->connection->remote_addr;
+    };
     static const char *get_user_agent(Handle *r)
     {
         const char *agent;
