@@ -1,7 +1,5 @@
 /******************************************************************************
- * mod_uploader / CharCodeConverter.h
- ******************************************************************************
- * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -24,85 +22,82 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CharCodeConverter.h 1003 2006-03-14 13:52:47Z svn $
+ * $Id: CharCodeConverter.h 2085 2006-11-25 19:29:52Z svn $
  *****************************************************************************/
 
 #ifndef CHAR_CODE_CONVERTER_H
 #define CHAR_CODE_CONVERTER_H
 
-#include "apr_pools.h"
+#include "Environment.h"
 
 #include <cstdlib>
 
-#ifdef HAVE_CONFIG_H
-#include "mod_uploader_config.h"
-#endif
+#include "apr_pools.h"
+
+#include "Uncopyable.h"
 
 using namespace std;
 
 /**
- * @brief ʸɤѴԤ饹
+ * @brief 文字コードの変換を行うクラス．
  */
-class CharCodeConverter
+class CharCodeConverter: public Uncopyable
 {
 public:
-    /** ǥեȤʸ */
+    /** デフォルトの文字コード */
     static const char DEFAULT_CODE[];
 
     /**
-     * ʸʸɤ򡤥ǥեȤΤΤѴޤ
+     * 文字列の文字コードを，デフォルトのものに変換します．
      *
-     * ʸʸɤϡpat ͤ˴ŤưŪȽ̤ޤ
+     * 入力文字列の文字コードは，pat の値に基づき自動的に判別されます．
      *
-     * @param[in] pool ס
-     * @param[in] str ʸ
-     * @param[in] pat ֵפ 1 Хܤ
-     * @return Ѵʸ
-     * @exception const char * ʸɤȽ̤Ǥʤä礪ӡʸɤѴ˼Ԥ硥
+     * @param[in] pool プール
+     * @param[in] str 入力文字列
+     * @param[in] pat 「京」の 1 バイト目の値
+     * @return 変換後の文字列
+     * @exception const char * 文字コードを判別できなかった場合および，文字コードの変換に失敗した場合．
      */
     static const char *convert(apr_pool_t *pool, const char *str,
                                const unsigned char *pat);
     /**
-     * Ϥʸɤto ǻᤵ줿Ѵޤ
+     * 入力の文字コードを，to で指令されたもの変換します．
      *
-     * @param[in] pool ס
-     * @param[in] str ʸ
-     * @param[in] from ʸʸ
-     * @param[in] to ʸʸ
-     * @return Ѵʸ
-     * @exception const char * ʸɤѴ˼Ԥ硥
+     * @param[in] pool プール
+     * @param[in] str 入力文字列
+     * @param[in] from 入力文字列の文字コード
+     * @param[in] to 出力文字列の文字コード
+     * @return 変換後の文字列
+     * @exception const char * 文字コードの変換に失敗した場合．
      */
     static const char *convert(apr_pool_t *pool, const char *str,
                                const char *from, const char *to);
 
 private:
-    /** ֵפ EUC-JP ɽ 1 Хܤ */
+    /** 「京」を EUC-JP で表現した場合の 1 バイト目の値 */
     static const unsigned char EUCJP_PAT_FIRST;
-    /** ֵפ Shift-JIS ɽ 1 Хܤ */
+    /** 「京」を Shift-JIS で表現した場合の 1 バイト目の値 */
     static const unsigned char SJIS_PAT_FIRST;
-    /** ֵפ JIS ɽ 1 Хܤ */
+    /** 「京」を JIS で表現した場合の 1 バイト目の値 */
     static const unsigned char JIS_PAT_FIRST;
-    /** ֵפ UTF-8 ɽ 1 Хܤ */
+    /** 「京」を UTF-8 で表現した場合の 1 バイト目の値 */
     static const unsigned char UTF8_PAT_FIRST;
 
     /**
-     * ֵפ 1 Хܤͤ˴ŤʸɤȽ̤ޤ
+     * 「京」の 1 バイト目の値に基づき，文字コードを判別します．
      *
-     * ʸɤEUC-JPShift-JISJISUTF-8 ΤǤʤ硤
-     * 㳰ꤲޤ
+     * 文字コードが，EUC-JP，Shift-JIS，JIS，UTF-8 のいずれでもない場合，
+     * 例外を投げます．
      *
-     * @param[in] pat ֵפ 1 Хܤ
-     * @exception const char * ʸɤȽ̤Ǥʤä硥
+     * @param[in] pat 「京」の 1 バイト目の値
+     * @exception const char * 文字コードを判別できなかった場合．
      */
     static const char *identify_code(const unsigned char *pat);
-
-    CharCodeConverter(const CharCodeConverter&);
-    CharCodeConverter &operator=(const CharCodeConverter&);
 };
 
 #endif
 
 // Local Variables:
 // mode: c++
-// buffer-file-coding-system: euc-japan-dos
+// coding: utf-8-dos
 // End:
