@@ -1,7 +1,5 @@
 /******************************************************************************
- * mod_uploader / ResponseWriter.h
- ******************************************************************************
- * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -24,35 +22,36 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ResponseWriter.h 1003 2006-03-14 13:52:47Z svn $
+ * $Id: ResponseWriter.h 2035 2006-11-23 16:14:21Z svn $
  *****************************************************************************/
 
 #ifndef RESPONSE_WRITER_H
 #define RESPONSE_WRITER_H
 
-#include "apr.h"
+#include "Environment.h"
 
 #include <cstdlib>
 
-#ifdef HAVE_CONFIG_H
-#include "mod_uploader_config.h"
-#endif
+#include "apr.h"
 
 using namespace std;
 
 /**
- * @brief 쥹ݥ󥹤񤭽Ф饹
+ * @brief レスポンスを書き出すクラス．
  */
 class ResponseWriter
 {
 public:
-    virtual void puts(const char *str) = 0;
-    virtual ~ResponseWriter();
+    // 効率が落ちるので virtual にはしたくない
+    void write(const char *str, apr_size_t length) throw();
+    void write(const char *str) throw();
+    void write(int i) throw();
+private:
 };
 
 #endif
 
 // Local Variables:
 // mode: c++
-// buffer-file-coding-system: euc-japan-dos
+// coding: utf-8-dos
 // End:
