@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 2173 2006-12-06 16:12:56Z svn $
+ * $Id: UploadItem.h 2202 2006-12-09 15:18:21Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_H
@@ -59,7 +59,10 @@ public:
         apr_size_t  index;
         apr_atomic_t download_count;
         bool        is_need_sync;
-        apr_off_t   file_size;
+        union {
+            apr_off_t   file_size;
+            char        dummy[8];
+        };
         apr_time_t  mtime;
         char        date[ITM_MAX_DATE_SIZE];
         char        ip_address[ITM_MAX_IP_ADDRESS_SIZE];
