@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.h 2144 2006-11-29 14:54:20Z svn $
+ * $Id: UploadItemManager.h 2168 2006-12-03 20:56:04Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_MANAGER_H
@@ -58,12 +58,12 @@ public:
      * @param[in] item_list スレッドのリスト
      */
     void init(UploadItemList *item_list, ThumbnailList *thumbnail_list);
-    void add(apr_pool_t *pool,
-             const char *file_name, const char *file_mime,
-             apr_off_t file_size, const char *file_digest,
-             const char *file_temp_path, const char *remove_pass,
-             const char *download_pass, const char *comment,
-             const char *ip_address);
+    apr_size_t add(apr_pool_t *pool,
+                   const char *file_name, const char *file_mime,
+                   apr_off_t file_size, const char *file_digest,
+                   const char *file_temp_path, const char *remove_pass,
+                   const char *download_pass, const char *comment,
+                   const char *ip_address);
     void remove(apr_pool_t *pool, UploadItem *uitem);
     UploadItem *get_item(apr_pool_t *pool, apr_size_t item_id);
     apr_file_t *get_item_file(apr_pool_t *pool, apr_size_t item_id);
