@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2061 2006-11-24 12:48:10Z svn $
+ * $Id: WriteLocker.h 2193 2006-12-09 01:26:55Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -53,7 +53,7 @@ public:
      * @param[in] can_nest_read 読み出しロックとネスト可能かどうか
      * @param[out] read_count 読み出し中のスレッドの数
      */
-    WriteLocker(apr_atomic_t *read_count, bool can_nest_read)
+    WriteLocker(apr_atomic_t *read_count, bool can_nest_read=false)
       : ReadWriteLocker(read_count)
     {
         if (can_nest_read)  {
@@ -62,16 +62,6 @@ public:
             lock();
         }
     };
-    /**
-     * コンストラクタです．
-     *
-     * @param[out] read_count 読み出し中のスレッドの数
-     */
-    WriteLocker(apr_atomic_t *read_count)
-      : ReadWriteLocker(read_count)
-    {
-        lock();
-    };
     ~WriteLocker()
     {
         apr_atomic_set(read_count_, 0);
