@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2077 2006-11-25 11:38:44Z svn $
+ * $Id: Auxiliary.cpp 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -47,7 +47,7 @@
 
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2077 2006-11-25 11:38:44Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2144 2006-11-29 14:54:20Z svn $");
 
 void init_atomic(apr_pool_t *pool)
 {
@@ -176,10 +176,12 @@ const char *get_file_ext(const char *file_name)
 {
     const char *file_ext;
 
-    if ((file_ext = strrchr(file_name, '.')) == NULL) {
-        THROW(MESSAGE_FILE_EXT_INVALID);
+    for (file_ext = file_name+strlen(file_name); file_ext != file_name;
+         file_ext--) {
+        if (*file_ext == '.') {
+            return ++file_ext;
+        }
     }
-    file_ext++;
 
     return file_ext;
 }
