@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CharCodeConverter.cpp 2179 2006-12-07 12:47:20Z svn $
+ * $Id: CharCodeConverter.cpp 2185 2006-12-08 17:25:48Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -38,10 +38,16 @@
 #if APU_HAVE_ICONV
 #include <iconv.h>
 #elif APU_HAVE_APR_ICONV
-#include <apr_iconv.h>
+#include "apr_iconv.h"
 #endif
+#include "apr_strings.h"
 
 #include "CharCodeConverter.h"
+#include "Message.h"
+#include "Macro.h"
+#include "SourceInfo.h"
+
+SOURCE_INFO_ADD("$Id: CharCodeConverter.cpp 2185 2006-12-08 17:25:48Z svn $");
 
 const char CharCodeConverter::DEFAULT_CODE[]            = SYS_CHARACTER_CODE;
 const unsigned char CharCodeConverter::EUCJP_PAT_FIRST  = 0xb5;
