@@ -22,18 +22,17 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.cpp 2168 2006-12-03 20:56:04Z svn $
+ * $Id: PostFlowController.cpp 2220 2006-12-10 06:10:27Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
 
 #include "PostFlowController.h"
+#include "ReadLocker.h"
+#include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2168 2006-12-03 20:56:04Z svn $");
-
-const apr_size_t PostFlowController::BUSY   = 1;
-const apr_size_t PostFlowController::FREE   = 0;
+SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2220 2006-12-10 06:10:27Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -43,22 +42,21 @@ PostFlowController::PostFlowController(apr_size_t min_post_interval_sec)
     poster_top_(0),
     poster_tail_(0)
 {
-    apr_atomic_set(&lock_, FREE);
+    apr_atomic_set(&lock_, ReadWriteLocker::NOT_LOCKER);
 }
 
-bool PostFlowController::can_post(const char *ip_address)
+bool PostFlowController::can_post(apr_sockaddr_t *ip_address)
 {
     apr_time_t last_post_time;
     apr_time_t post_interval_time;
     bool can_post;
 
-    while (apr_atomic_cas(&lock_, BUSY, FREE) != FREE);
+    ReadLocker lock(&lock_);
 
     // MEMO: 短時間の間に異なる ARRAY_SIZE_OF(poster_list_) 個の IP ア
     // ドレスから投稿があった場合，制限に漏れが生じる．
 
-    last_post_time = poster_list_is_contain
-        (ip_address, static_cast<char>(strlen(ip_address) & 0xff));
+    last_post_time = poster_list_is_contain(ip_address);
 
     if (last_post_time == 0) {
         can_post = true;
@@ -72,16 +70,14 @@ bool PostFlowController::can_post(const char *ip_address)
         }
     }
 
-    while (apr_atomic_cas(&lock_, FREE, BUSY) != BUSY);
-
     return can_post;
 }
 
-void PostFlowController::regist_post(const char *ip_address)
+void PostFlowController::regist_post(apr_sockaddr_t *ip_address)
 {
-    while (apr_atomic_cas(&lock_, BUSY, FREE) != FREE);
-    poster_list_add(ip_address, static_cast<char>(strlen(ip_address) & 0xff));
-    while (apr_atomic_cas(&lock_, FREE, BUSY) != BUSY);
+    WriteLocker lock(&lock_);
+
+    poster_list_add(ip_address);
 }
 
 PostFlowController *PostFlowController::get_instance(apr_shm_t *shm,
@@ -127,8 +123,7 @@ void PostFlowController::dump_list(PostFlowController *flow_controller)
 /******************************************************************************
  * private メソッド
  *****************************************************************************/
-void PostFlowController::poster_list_add(const char *ip_address,
-                                         char ip_address_length)
+void PostFlowController::poster_list_add(apr_sockaddr_t *ip_address)
 {
     poster_top_++;
     if (poster_top_ == ARRAY_SIZE_OF(poster_list_)) {
@@ -141,9 +136,8 @@ void PostFlowController::poster_list_add(const char *ip_address,
         }
     }
 
-    poster_list_[poster_top_].ip_address[0] = ip_address_length;
-    memcpy(&(poster_list_[poster_top_].ip_address[1]), ip_address,
-           ip_address_length);
+    memcpy(&(poster_list_[poster_top_].ip_address), &(ip_address->sa),
+           sizeof(ip_address->sa));
     poster_list_[poster_top_].time = apr_time_now();
 }
 
@@ -163,8 +157,7 @@ void PostFlowController::poster_list_clean()
     poster_tail_ = i;
 }
 
-apr_time_t PostFlowController::poster_list_is_contain(const char *ip_address,
-                                                      char ip_address_length) const
+apr_time_t PostFlowController::poster_list_is_contain(apr_sockaddr_t *ip_address) const
 {
     apr_size_t i;
 
@@ -174,12 +167,8 @@ apr_time_t PostFlowController::poster_list_is_contain(const char *ip_address,
 
     i = poster_top_;
     do {
-        if (poster_list_[i].ip_address[0] != ip_address_length) {
-            continue;
-        }
-
-        if (memcmp(ip_address, &(poster_list_[i].ip_address[1]),
-                   ip_address_length) != 0) {
+        if (memcmp(&(poster_list_[i].ip_address), &(ip_address->sa),
+                   sizeof(ip_address->sa)) != 0) {
             continue;
         }
         return poster_list_[i].time;
@@ -192,7 +181,12 @@ apr_time_t PostFlowController::poster_list_is_contain(const char *ip_address,
 
 void PostFlowController::dump_poster(poster_t *poster)
 {
-    cerr.write(&(poster->ip_address[1]), poster->ip_address[0]) << endl;
+    apr_size_t *address;
+
+    // 強引にキャスト
+    address = reinterpret_cast<apr_size_t *>(&(poster->ip_address));
+
+    cerr << *address << endl;
 }
 
 
@@ -202,8 +196,6 @@ void PostFlowController::dump_poster(poster_t *poster)
 #ifdef DEBUG_PostFlowController
 #include "TestRunner.h"
 
-#include "apr_time.h"
-
 const char DUMMY_IP_ADDRESS[]           = "127.0.0.1";
 const apr_time_t MIN_POST_INTERVAL_SEC  = 1;
 const apr_size_t ATTACK_COUNT           = 100;
