@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailList.cpp 2170 2006-12-04 17:23:49Z svn $
+ * $Id: ThumbnailList.cpp 2201 2006-12-09 02:51:13Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -37,7 +37,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ThumbnailList.cpp 2170 2006-12-04 17:23:49Z svn $");
+SOURCE_INFO_ADD("$Id: ThumbnailList.cpp 2201 2006-12-09 02:51:13Z svn $");
 
 #define AS_THUMBNAIL_LIST(pointer)  reinterpret_cast<ThumbnailList *>(pointer)
 
@@ -96,6 +96,10 @@ void ThumbnailList::remove(apr_size_t item_id)
                 sizeof(apr_size_t) * (*thumbnail_list_size_ - i - 1));
     }
 
+    if (*thumbnail_list_size_ == 0) { // 念のため
+        THROW(MESSAGE_BUG_FOUND);
+    }
+
     (*thumbnail_list_size_)--;
 }
 
