@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemListReader.cpp 2144 2006-11-29 14:54:20Z svn $
+ * $Id: UploadItemListReader.cpp 2173 2006-12-06 16:12:56Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2144 2006-11-29 14:54:20Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2173 2006-12-06 16:12:56Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -54,6 +54,7 @@ UploadItemList *UploadItemListReader::read(apr_pool_t *pool,
                                            const char *thumb_dir_path,
                                            apr_shm_t *shm,
                                            ThumbnailList *thumbnail_list,
+                                           apr_uint64_t max_file_size,
                                            apr_size_t max_list_size)
 {
     UploadItemList *item_list;
@@ -69,7 +70,8 @@ UploadItemList *UploadItemListReader::read(apr_pool_t *pool,
         THROW(MESSAGE_UPLOAD_ITEM_DIR_OPEN_FAILED);
     }
 
-    item_list = UploadItemList::get_instance(shm, max_list_size);
+    item_list = UploadItemList::get_instance(shm,
+                                             max_file_size, max_list_size);
 
     while (apr_dir_read(&sub_dir_info, APR_FINFO_NAME|APR_FINFO_TYPE,
                         dir) == APR_SUCCESS) {
