@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemVariableCreator.cpp 2144 2006-11-29 14:54:20Z svn $
+ * $Id: UploadItemVariableCreator.cpp 2175 2006-12-06 17:27:48Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,7 +32,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2144 2006-11-29 14:54:20Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2175 2006-12-06 17:27:48Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -207,6 +207,7 @@ apr_size_t UploadItemVariableCreator::get_item_memory_size() const
 #include "Message.h"
 
 static const apr_size_t ITEM_LIST_SIZE  = 10;
+static const apr_uint64_t MAX_FILE_SIZE = 1000000;
 static const apr_size_t MAX_LIST_SIZE   = 1000;
 
 void show_usage(const char *prog_name)
@@ -262,8 +263,9 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
 
     thumbnail_list = ThumbnailList::get_instance(thumbnail_list_shm,
                                                  MAX_LIST_SIZE);
-    item_list = UploadItemListReader::read(pool, data_dir_path, item_list_shm,
-                                           thumbnail_list, MAX_LIST_SIZE);
+    item_list = UploadItemListReader::read(pool, data_dir_path, data_dir_path,
+                                           item_list_shm, thumbnail_list,
+                                           MAX_FILE_SIZE, MAX_LIST_SIZE);
 
     show_item("data dir", data_dir_path);
     show_item("template file", tmpl_file_path);
