@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderTemplate.cpp 2080 2006-11-25 14:22:47Z svn $
+ * $Id: UploaderTemplate.cpp 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -36,10 +36,11 @@
 #include "TemplateLexer.h"
 #include "TemplateVariableCreator.h"
 #include "UploadItemVariableCreator.h"
+#include "ThumbnailVariableCreator.h"
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderTemplate.cpp 2080 2006-11-25 14:22:47Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderTemplate.cpp 2144 2006-11-29 14:54:20Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -50,11 +51,14 @@ UploaderTemplate::UploaderTemplate(apr_pool_t *pool, const char *file_path)
     file_path_(file_path),
     node_shm_(NULL),
     ids_and_keys_shm_(NULL),
-    var_creator_shm_(NULL),
+    item_var_creator_shm_(NULL),
+    thumbnail_var_creator_shm_(NULL),
     node_tree_(NULL),
     ids_(NULL),
     keys_(NULL),
-    key_count_(0)
+    key_count_(0),
+    item_var_creator_(NULL),
+    thumbnail_var_creator_(NULL)
 {
 
 }
@@ -63,12 +67,14 @@ void UploaderTemplate::load()
 {
     apr_shm_t *node_shm;
     apr_shm_t *ids_and_keys_shm;
-    apr_shm_t *var_creator_shm;
+    apr_shm_t *item_var_creator_shm;
+    apr_shm_t *thumbnail_var_creator_shm;
     const node_t *node_tree;
     const char **ids;
     const char **keys;
     apr_size_t key_count;
     UploadItemVariableCreator *item_var_creator;
+    ThumbnailVariableCreator *thumbnail_var_creator;
     Lexer *lexer;
     TemporaryPool *tmpl_pool;
 
@@ -100,16 +106,21 @@ void UploaderTemplate::load()
          VariableCreator::get_array_memory_size(lexer->get_id_array()));
     key_count = VariableCreator::get_entry_count(keys);
 
-    var_creator_shm = create_shm
+    item_var_creator_shm = create_shm
         (tmpl_pool->get(), sizeof(UploadItemVariableCreator));
+    thumbnail_var_creator_shm = create_shm
+        (tmpl_pool->get(), sizeof(ThumbnailVariableCreator));
 
     item_var_creator = UploadItemVariableCreator::get_instance
-        (apr_shm_baseaddr_get(var_creator_shm), keys);
+        (apr_shm_baseaddr_get(item_var_creator_shm), keys);
+    thumbnail_var_creator = ThumbnailVariableCreator::get_instance
+        (apr_shm_baseaddr_get(thumbnail_var_creator_shm), keys);
 
     if (tmpl_pool_ != NULL) {
         apr_shm_destroy(node_shm_);
         apr_shm_destroy(ids_and_keys_shm_);
-        apr_shm_destroy(var_creator_shm_);
+        apr_shm_destroy(item_var_creator_shm_);
+        apr_shm_destroy(thumbnail_var_creator_shm_);
 
         delete tmpl_pool_;
     }
@@ -118,7 +129,8 @@ void UploaderTemplate::load()
 
     node_shm_          = node_shm;
     ids_and_keys_shm_  = ids_and_keys_shm;
-    var_creator_shm_   = var_creator_shm;
+    item_var_creator_shm_       = item_var_creator_shm;
+    thumbnail_var_creator_shm_  = thumbnail_var_creator_shm;
 
     node_tree_  = node_tree;
     ids_        = ids;
@@ -126,6 +138,7 @@ void UploaderTemplate::load()
     key_count_  = key_count;
 
     item_var_creator_ = item_var_creator;
+    thumbnail_var_creator_ = thumbnail_var_creator;
 
     File tmpl_file(tmpl_pool_->get(), file_path_);
     mtime_ = tmpl_file.get_mtime();
