@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2179 2006-12-07 12:47:20Z svn $
+ * $Id: uploader_handler.cpp 2220 2006-12-10 06:10:27Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -48,6 +48,7 @@
 #include "UploadItemManager.h"
 #include "ThumbnailIterator.h"
 #include "ThumbnailVariableCreator.h"
+#include "PostProgressList.h"
 #include "CharCodeConverter.h"
 #include "Message.h"
 #include "Macro.h"
@@ -55,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2179 2006-12-07 12:47:20Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2220 2006-12-10 06:10:27Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -83,6 +84,7 @@ static const char DOWNLOAD_COMMAND[]            = "download";
 static const char REMOVE_COMMAND[]              = "remove";
 static const char RSS_COMMAND[]                 = "rss";
 static const char UPLOAD_COMMAND[]              = "upload";
+static const char PROGRESS_DATA_COMMAND[]       = "progress_data";
 static const char ADMIN_COMMAND[]               = "admin";
 
 #ifdef DEBUG
@@ -399,7 +401,7 @@ static int upload_impl(typename Response::Handle *r, UploaderConfig *config,
          file_temp_path, remove_pass, download_pass, comment,
          Response::get_remote_ip(r));
 
-    regist_post(config, Response::get_remote_ip(r));
+    regist_post(config, Response::get_remote_addr(r));
 
     Response::set_env(r, "uploader_upload", "");
     Response::set_env(r, "uploader_item_id", apr_itoa(r->pool, item_id));
@@ -412,7 +414,9 @@ template<class Response>
 static int upload(typename Response::Handle *r, UploaderConfig *config,
                   const char *arg)
 {
-    int status;
+    apr_uint32_t upload_id;
+    RequestReader::post_progress_t *progress;
+    apr_array_header_t *content_array;
 
     const char *file_name;
     const char *file_mime;
@@ -423,8 +427,7 @@ static int upload(typename Response::Handle *r, UploaderConfig *config,
     const char *download_pass;
     const char *comment;
 
-    RequestReader::progress_t progress;
-    apr_array_header_t *content_array;
+    int status;
 
     if (!Response::is_post_method(r)) {
         return HTTP_BAD_REQUEST;
@@ -434,18 +437,30 @@ static int upload(typename Response::Handle *r, UploaderConfig *config,
         return status;
     }
 
-    if (!can_post(config, Response::get_remote_ip(r))) {
+    if (!can_post(config, Response::get_remote_addr(r))) {
         return error<Response>(r, config, MESSAGE_POST_INTERVAL_TOO_SHORT);
     }
 
-    typename Response::Reader i(&progress, r);
+    upload_id = static_cast<apr_size_t>
+        (apr_atoi64(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])));
+
+    progress = config->get_post_progress_list()->add(upload_id);
+
+    typename Response::Reader i(progress, r);
     RFC1867Parser<typename Response::Reader> parser
         (r->pool, i, config->temp_dir_path,
          ITM_MAX_COMMENT_SIZE, config->file_size_limit,
          PST_MAX_ITEM_COUNT);
 
-    content_array = parser.parse(Response::get_content_type(r),
-                                 Response::get_content_size(r));
+    progress->total_size = Response::get_content_size(r);
+    try {
+        content_array = parser.parse(Response::get_content_type(r),
+                                     Response::get_content_size(r));
+        progress->end_time = apr_time_now();
+    } catch(const char *message) {
+        progress->end_time = apr_time_now();
+        return error_with_log<Response>(r, config, message);
+    }
 
     file_temp_path = NULL;
     try {
@@ -454,10 +469,14 @@ static int upload(typename Response::Handle *r, UploaderConfig *config,
              &file_name, &file_mime, &file_size, &file_digest, &file_temp_path,
              &remove_pass, &download_pass, &comment);
 
-        return upload_impl<Response>
+        status = upload_impl<Response>
             (r, config,
              file_name, file_mime, file_size, file_digest, file_temp_path,
              remove_pass, download_pass, comment);
+
+        progress->is_succeeded  = true;
+
+        return status;
     } catch(const char *message) {
         if (file_temp_path != NULL) {
             apr_file_remove(file_temp_path, r->pool);
@@ -466,6 +485,46 @@ static int upload(typename Response::Handle *r, UploaderConfig *config,
     }
 }
 
+template<class Response>
+static int progress_data(typename Response::Handle *r, UploaderConfig *config,
+                         const char *arg)
+{
+    apr_uint32_t upload_id;
+    RequestReader::post_progress_t *progress;
+
+    upload_id = static_cast<apr_size_t>
+        (apr_atoi64(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])));
+
+    typename Response::Writer o(r);
+
+    // upload_id が 0 の時はエラー．
+    if (UNLIKELY(upload_id == 0)) {
+        o.write("e");
+        o.finish();
+
+        return OK;
+    }
+
+    progress = config->get_post_progress_list()->get(upload_id);
+
+    // ダミーかどうかチェック
+    if (UNLIKELY(progress->id != upload_id)) {
+        o.write("u");
+        o.finish();
+
+        return OK;
+    }
+
+    o.write(apr_psprintf(r->pool, "%c %" APR_UINT64_T_FMT " %" APR_UINT64_T_FMT,
+                         ((progress->end_time != PostProgressList::ENTRY_USED) &&
+                          progress->is_succeeded)
+                         ? 'S' : 's',
+                         progress->total_size, progress->read_size));
+    o.finish();
+
+    return OK;
+}
+
 template<class Response>
 static int mail_upload(typename Response::Handle *r, UploaderConfig *config,
                        const char *arg)
@@ -481,7 +540,7 @@ static int mail_upload(typename Response::Handle *r, UploaderConfig *config,
     const char *download_pass;
     const char *comment;
 
-    RequestReader::progress_t progress;
+    RequestReader::post_progress_t progress;
     apr_array_header_t *content_array;
 
     if (!Response::is_post_method(r)) {
@@ -584,7 +643,7 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
         const char *dispos_encoding;
 
         if (Response::is_post_method(r)) {
-            RequestReader::progress_t progress;
+            RequestReader::post_progress_t progress;
             apr_array_header_t *content_array;
             int status;
 
@@ -617,40 +676,53 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
             }
         }
 
-        Response::set_content_type(r, uitem->get_file_mime());
+        if (!can_download(config, Response::get_remote_addr(r))) {
+            THROW(MESSAGE_DOWNLOAD_SESSION_LIMIT_EXCEEDED);
+        }
+
+        try {
+            Response::set_content_type(r, uitem->get_file_mime());
 #ifndef DEBUG
-        Response::set_modified_time(r, uitem->get_mtime());
-        Response::set_last_modified(r, uitem->get_mtime());
+            Response::set_modified_time(r, uitem->get_mtime());
+            Response::set_last_modified(r, uitem->get_mtime());
 
-        int status;
-        if ((status = Response::is_meets_condition(r)) != OK) {
-            return status;
-        }
+            int status;
+            if ((status = Response::is_meets_condition(r)) != OK) {
+                finish_download(config, Response::get_remote_addr(r));
+                return status;
+            }
 #endif
-        if (Response::is_head_method(r)) {
-            return OK;
+            if (Response::is_head_method(r)) {
+                finish_download(config, Response::get_remote_addr(r));
+                return OK;
+            }
+
+            item_file = config->get_item_manager()->get_item_file(r->pool,
+                                                                  item_id);
+
+            Response::set_accept_ranges(r);
+
+            dispos_encoding = get_dispos_encoding(Response::get_user_agent(r));
+            file_name = CharCodeConverter::convert
+                (r->pool, uitem->get_file_name(),
+                 CharCodeConverter::DEFAULT_CODE, dispos_encoding);
+
+            // 表示モード or ダウンロードモード
+            open_mode = (strlen(get_word(r->pool, &arg,
+                                         ARG_SEPARATE_STR[0])) == 0)
+                ? "inline" : "attachment";
+            // Content-Disposition
+            Response::set_content_disposition
+                (r,
+                 apr_psprintf(r->pool, "%s; filename=\"%s\"", open_mode,
+                              file_name));
+
+            Response::Writer::sendfile(r, item_file, uitem->get_file_size());
+            finish_download(config, Response::get_remote_addr(r));
+        } catch(const char *) {
+            finish_download(config, Response::get_remote_addr(r));
+            throw;
         }
-
-        item_file = config->get_item_manager()->get_item_file(r->pool,
-                                                              item_id);
-
-        Response::set_accept_ranges(r);
-
-        dispos_encoding = get_dispos_encoding(Response::get_user_agent(r));
-        file_name = CharCodeConverter::convert(r->pool, uitem->get_file_name(),
-                                               CharCodeConverter::DEFAULT_CODE,
-                                               dispos_encoding);
-
-        // 表示モード or ダウンロードモード
-        open_mode = (strlen(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])) == 0)
-            ? "inline" : "attachment";
-        // Content-Disposition
-        Response::set_content_disposition
-            (r,
-             apr_psprintf(r->pool, "%s; filename=\"%s\"", open_mode,
-                          file_name));
-
-        Response::Writer::sendfile(r, item_file, uitem->get_file_size());
     } catch(const char *message) {
         return error<Response>(r, config, message);
     }
@@ -677,7 +749,7 @@ static int remove(typename Response::Handle *r, UploaderConfig *config,
         UploadItem *uitem;
         apr_size_t item_id;
         const char *remove_pass;
-        RequestReader::progress_t progress;
+        RequestReader::post_progress_t progress;
         apr_array_header_t *content_array;
 
         typename Response::Reader i(&progress, r);
@@ -897,6 +969,8 @@ int uploader_command_handler(typename Response::Handle *r, UploaderConfig *confi
         return thumbnail<Response>(r, config, arg);
     } else if (IS_REQUEST_COMMAND(command, UPLOAD_COMMAND)) {
         return upload<Response>(r, config, arg);
+    } else if (IS_REQUEST_COMMAND(command, PROGRESS_DATA_COMMAND)) {
+        return progress_data<Response>(r, config, arg);
     } else if (IS_REQUEST_COMMAND(command, DOWNLOAD_COMMAND)) {
         return download<Response>(r, config, arg);
     } else if (strcmp(command, REMOVE_COMMAND) == 0) {
