@@ -61,6 +61,8 @@ namespace UploaderConfig
                 uploaderConfig.thumbnailTmplPath);
             buffer.AppendFormat("UploaderAdminViewTemplate      \"{0}\"\r\n",
                 uploaderConfig.adminTmplPath);
+            buffer.AppendFormat("UploaderErrorViewTemplate      \"{0}\"\r\n",
+                uploaderConfig.errorTmplPath);
 
             buffer.AppendFormat("Alias /up_img                  \"{0}\"\r\n",
                 uploaderConfig.imageDirPath);
