@@ -86,6 +86,10 @@
             this.perPageItemNumberNumericUpDown = new System.Windows.Forms.NumericUpDown();
             this.fileSizeLimitNumericUpDown = new System.Windows.Forms.NumericUpDown();
             this.tabPage3 = new System.Windows.Forms.TabPage();
+            this.errorTmplPathLabel = new System.Windows.Forms.Label();
+            this.errorTmplPathTextBox = new System.Windows.Forms.TextBox();
+
+            this.errorTmplPathButton = new System.Windows.Forms.Button();
             this.adminTmplPathButton = new System.Windows.Forms.Button();
             this.adminTmplPathTextBox = new System.Windows.Forms.TextBox();
             this.downloadTmplPathButton = new System.Windows.Forms.Button();
@@ -117,6 +121,7 @@
             ((System.ComponentModel.ISupportInitialize)(this.perPageItemNumberNumericUpDown)).BeginInit();
             ((System.ComponentModel.ISupportInitialize)(this.fileSizeLimitNumericUpDown)).BeginInit();
             this.tabPage3.SuspendLayout();
+
             ((System.ComponentModel.ISupportInitialize)(this.errorProvider)).BeginInit();
             this.groupBox1.SuspendLayout();
             this.menuToolStrip.SuspendLayout();
@@ -713,6 +718,9 @@
             // tabPage3
             // 
             this.tabPage3.AutoScroll = true;
+            this.tabPage3.Controls.Add(this.errorTmplPathLabel);
+            this.tabPage3.Controls.Add(this.errorTmplPathTextBox);
+            this.tabPage3.Controls.Add(this.errorTmplPathButton);
             this.tabPage3.Controls.Add(this.adminTmplPathButton);
             this.tabPage3.Controls.Add(this.adminTmplPathLabel);
             this.tabPage3.Controls.Add(this.adminTmplPathTextBox);
@@ -735,6 +743,38 @@
             this.tabPage3.Text = "テンプレート";
             this.tabPage3.UseVisualStyleBackColor = true;
             // 
+            // errorTmplPathLabel
+            // 
+            this.errorTmplPathLabel.AutoSize = true;
+            this.errorTmplPathLabel.Location = new System.Drawing.Point(8, 208);
+            this.errorTmplPathLabel.Name = "errorTmplPathLabel";
+            this.errorTmplPathLabel.Size = new System.Drawing.Size(126, 12);
+            this.errorTmplPathLabel.TabIndex = 18;
+            this.errorTmplPathLabel.Text = "エラーページのテンプレート";
+            // 
+            // errorTmplPathTextBox
+            // 
+            this.errorTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "errorTmplPath", true));
+            this.errorTmplPathTextBox.Location = new System.Drawing.Point(8, 224);
+            this.errorTmplPathTextBox.Name = "errorTmplPathTextBox";
+            this.errorTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
+            this.errorTmplPathTextBox.TabIndex = 17;
+            this.errorTmplPathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
+            // 
+            // uploaderConfigBindingSource1
+            // 
+
+            // 
+            // errorTmplPathButton
+            // 
+            this.errorTmplPathButton.Location = new System.Drawing.Point(384, 224);
+            this.errorTmplPathButton.Name = "errorTmplPathButton";
+            this.errorTmplPathButton.Size = new System.Drawing.Size(56, 23);
+            this.errorTmplPathButton.TabIndex = 15;
+            this.errorTmplPathButton.Text = "参照";
+            this.errorTmplPathButton.UseVisualStyleBackColor = true;
+            this.errorTmplPathButton.Click += new System.EventHandler(this.errorTmplPathButton_Click);
+            // 
             // adminTmplPathButton
             // 
             this.adminTmplPathButton.Location = new System.Drawing.Point(384, 184);
@@ -943,6 +983,7 @@
             ((System.ComponentModel.ISupportInitialize)(this.fileSizeLimitNumericUpDown)).EndInit();
             this.tabPage3.ResumeLayout(false);
             this.tabPage3.PerformLayout();
+
             ((System.ComponentModel.ISupportInitialize)(this.errorProvider)).EndInit();
             this.groupBox1.ResumeLayout(false);
             this.groupBox1.PerformLayout();
@@ -1031,5 +1072,9 @@
         private System.Windows.Forms.TextBox imageDirPathTextBox;
         private System.Windows.Forms.Label thumbDirPathLabel;
         private System.Windows.Forms.ToolStripButton apacheStripButton;
+        private System.Windows.Forms.Label errorTmplPathLabel;
+        private System.Windows.Forms.TextBox errorTmplPathTextBox;
+
+        private System.Windows.Forms.Button errorTmplPathButton;
     }
 }
\ No newline at end of file
