@@ -94,7 +94,8 @@ namespace UploaderConfig
                 new CancelEventHandler((new FilePathValidator(thumbnailTmplPathLabel, errorProvider)).validate);
             adminTmplPathTextBox.Validating +=
                 new CancelEventHandler((new FilePathValidator(adminTmplPathLabel, errorProvider)).validate);
-
+            errorTmplPathTextBox.Validating +=
+                new CancelEventHandler((new FilePathValidator(errorTmplPathLabel, errorProvider)).validate);
         }
 
         private void modulePathButton_Click(object sender, EventArgs e)
@@ -209,6 +210,20 @@ namespace UploaderConfig
             ValidateChildren();
         }
 
+        private void errorTmplPathButton_Click(object sender, EventArgs e)
+        {
+            string file_path = chooseTemplateFile(errorTmplPathLabel,
+                errorTmplPathTextBox.Text);
+
+            if (file_path == null) {
+                return;
+            }
+
+            uploaderConfig.errorTmplPath = file_path;
+            uploaderConfigBindingSource.ResetBindings(false);
+            ValidateChildren();
+        }
+
         private void dataDirPathButton_Click(object sender, EventArgs e)
         {
             string folder_path = chooseFolder(dataDirPathLabel, 
